@@ -87,6 +87,8 @@ __PACKAGE__->add_columns(
   { data_type => "boolean", is_nullable => 1 },
   "custom_fields",
   { data_type => "jsonb", is_nullable => 0, default_value => \"{}" },
+  "tags",
+  { data_type => "text[]", is_nullable => 0, default_value => \"'{}'::text[]" },
 );
 __PACKAGE__->set_primary_key("ip");
 
