@@ -338,15 +338,26 @@ sub jq_insert {
           if ($spec->{port}) {
               $row = schema(vars->{'tenant'})->resultset('DevicePort')
                                              ->find($spec->{port}, $spec->{device});
+              undef $row unless
+                scalar grep {('cf_'. $_) eq $spec->{action}}
+                            grep {defined}
+                            map {$_->{name}}
+                            @{ setting('custom_fields')->{device_port} || [] };
           }
           else {
               $row = schema(vars->{'tenant'})->resultset('Device')
                                              ->find($spec->{device});
+              undef $row unless
+                scalar grep {('cf_'. $_) eq $spec->{action}}
+                            grep {defined}
+                            map {$_->{name}}
+                            @{ setting('custom_fields')->{device} || [] };
           }
+
           die 'failed to find row for custom field update' unless $row;
 
           $spec->{action} =~ s/^cf_//;
-          $spec->{subaction} = to_json( $spec->{subaction} );
+          $spec->{subaction} = to_json( $spec->{extra} || $spec->{subaction} );
           $row->make_column_dirty('custom_fields');
           $row->update({
             custom_fields => \['jsonb_set(custom_fields, ?, ?)'
